/********************************************************************
 *                   NASA CONFIDENTIAL INFORMATION                  *
 *                 (c)2003 Nasa Ames Research Center				        *
 *                        All Rights Reserved                       *
 *                                                                  *
 *  This program contains confidential and proprietary information  *
 *  of NASA Ames Research Center, any reproduction, disclosure,     *
 *  or use in whole or in part is expressly prohibited, except as   *
 *  may be specifically authorized by prior written agreement.      *
 *                                                                  *
 ********************************************************************/
package brahms.base;

/**
 * The Calendar class defines the attributes necessary to reason
 * about dates and times. Combined with the set of external activities
 * available in the CalendarUtilGroup and CalendarUtilClass it is
 * possible to perform a variety of operations using Calendars.
 *
 * @author Ron van Hoof
 * @version 13 August 2003
 */
class Calendar {
	attributes:
		public int date;				// 1 - 31
		public int month;				// 1 - 12	(1 = January, 12 = December)
		public int year;				// 4 digits to represent the year, 2003	not 03
		public int hour;				// 0 - 23
		public int minute;			// 0 - 59
		public int second;			// 0 - 59
		public int millisecond;	// 0 - 999
		public int dayOfWeek;		// 1 - 7	(1 = Sunday, 7 = Saturday)
		public int dayOfMonth;	// 1 - 31
		public int dayOfWeekInMonth;	// 1 - 5	(for example 2 for 2nd Wednesday in August)
		public int weekOfMonth; // 1 - 5
		public int weekOfYear;	// 1 - 52
		
		public string timeZone;	// full timezone name (see valid timezone names below)
		public string timeZoneShort;	// three character abbreviation for timezone (not to be used for setting timezones)
		
		public string sMonth;			// January, February, March, April, May, June, July, August, September, October, November, December
		public string sDayOfWeek;	// Sunday, Monday, Tuesday, Wednesday, Thursday, Friday, Saturyday
		
		public string timeStamp;	// formatted as "MM/dd/yyyy HH:mm:ss zzzz" 
															// where HH is military time (0-23) and
															// where zzzz is the full timezone name
} // Calendar

/*
 * THESE ARE THE ONLY VALID FULL TIMEZONE NAMES TO BE USED FOR THE timeZone ATTRIBUTE!
 * THE USE OF ANY OTHER NAMES WILL RESULT IN DATES/TIMES BEING DEFAULTED TO GMT.
 * 
 * MIT
 * Pacific/Apia
 * Pacific/Niue
 * Pacific/Pago_Pago
 * America/Adak
 * HST
 * Pacific/Fakaofo
 * Pacific/Honolulu
 * Pacific/Rarotonga
 * Pacific/Tahiti
 * Pacific/Marquesas
 * AST
 * America/Anchorage
 * Pacific/Gambier
 * America/Los_Angeles
 * America/Tijuana
 * America/Vancouver
 * PST
 * Pacific/Pitcairn
 * America/Dawson_Creek
 * America/Denver
 * America/Edmonton
 * America/Mazatlan
 * America/Phoenix
 * MST
 * PNT
 * America/Belize
 * America/Chicago
 * America/Costa_Rica
 * America/El_Salvador
 * America/Guatemala
 * America/Managua
 * America/Mexico_City
 * America/Regina
 * America/Tegucigalpa
 * America/Winnipeg
 * CST
 * Pacific/Easter
 * Pacific/Galapagos
 * America/Bogota
 * America/Cayman
 * America/Grand_Turk
 * America/Guayaquil
 * America/Havana
 * America/Indianapolis
 * America/Jamaica
 * America/Lima
 * America/Montreal
 * America/Nassau
 * America/New_York
 * America/Panama
 * America/Port-au-Prince
 * America/Porto_Acre
 * America/Rio_Branco
 * EST
 * IET
 * America/Anguilla
 * America/Antigua
 * America/Aruba
 * America/Asuncion
 * America/Barbados
 * America/Caracas
 * America/Cuiaba
 * America/Curacao
 * America/Dominica
 * America/Grenada
 * America/Guadeloupe
 * America/Guyana
 * America/Halifax
 * America/La_Paz
 * America/Manaus
 * America/Martinique
 * America/Montserrat
 * America/Port_of_Spain
 * America/Puerto_Rico
 * America/Santiago
 * America/Santo_Domingo
 * America/St_Kitts
 * America/St_Lucia
 * America/St_Thomas
 * America/St_Vincent
 * America/Thule
 * America/Tortola
 * Antarctica/Palmer
 * Atlantic/Bermuda
 * Atlantic/Stanley
 * PRT
 * America/St_Johns
 * CNT
 * AGT
 * America/Buenos_Aires
 * America/Cayenne
 * America/Fortaleza
 * America/Godthab
 * America/Miquelon
 * America/Montevideo
 * America/Paramaribo
 * America/Sao_Paulo
 * BET
 * America/Noronha
 * Atlantic/South_Georgia
 * America/Scoresbysund
 * Atlantic/Azores
 * Atlantic/Cape_Verde
 * Atlantic/Jan_Mayen
 * Africa/Abidjan
 * Africa/Accra
 * Africa/Banjul
 * Africa/Bissau
 * Africa/Casablanca
 * Africa/Conakry
 * Africa/Dakar
 * Africa/Freetown
 * Africa/Lome
 * Africa/Monrovia
 * Africa/Nouakchott
 * Africa/Ouagadougou
 * Africa/Sao_Tome
 * Africa/Timbuktu
 * Atlantic/Canary
 * Atlantic/Faeroe
 * Atlantic/Reykjavik
 * Atlantic/St_Helena
 * Europe/Dublin
 * Europe/Lisbon
 * Europe/London
 * GMT
 * UTC
 * WET
 * Africa/Algiers
 * Africa/Bangui
 * Africa/Douala
 * Africa/Kinshasa
 * Africa/Lagos
 * Africa/Libreville
 * Africa/Luanda
 * Africa/Malabo
 * Africa/Ndjamena
 * Africa/Niamey
 * Africa/Porto-Novo
 * Africa/Tunis
 * Africa/Windhoek
 * ECT
 * Europe/Amsterdam
 * Europe/Andorra
 * Europe/Belgrade
 * Europe/Berlin
 * Europe/Brussels
 * Europe/Budapest
 * Europe/Copenhagen
 * Europe/Gibraltar
 * Europe/Luxembourg
 * Europe/Madrid
 * Europe/Malta
 * Europe/Monaco
 * Europe/Oslo
 * Europe/Paris
 * Europe/Prague
 * Europe/Rome
 * Europe/Stockholm
 * Europe/Tirane
 * Europe/Vaduz
 * Europe/Vienna
 * Europe/Warsaw
 * Europe/Zurich
 * ART
 * Africa/Blantyre
 * Africa/Bujumbura
 * Africa/Cairo
 * Africa/Gaborone
 * Africa/Harare
 * Africa/Johannesburg
 * Africa/Kigali
 * Africa/Lubumbashi
 * Africa/Lusaka
 * Africa/Maputo
 * Africa/Maseru
 * Africa/Mbabane
 * Africa/Tripoli
 * Asia/Amman
 * Asia/Beirut
 * Asia/Damascus
 * Asia/Jerusalem
 * Asia/Nicosia
 * CAT
 * EET
 * Europe/Athens
 * Europe/Bucharest
 * Europe/Chisinau
 * Europe/Helsinki
 * Europe/Istanbul
 * Europe/Kaliningrad
 * Europe/Kiev
 * Europe/Minsk
 * Europe/Riga
 * Europe/Simferopol
 * Europe/Sofia
 * Europe/Tallinn
 * Europe/Vilnius
 * Africa/Addis_Ababa
 * Africa/Asmera
 * Africa/Dar_es_Salaam
 * Africa/Djibouti
 * Africa/Kampala
 * Africa/Khartoum
 * Africa/Mogadishu
 * Africa/Nairobi
 * Asia/Aden
 * Asia/Baghdad
 * Asia/Bahrain
 * Asia/Kuwait
 * Asia/Qatar
 * Asia/Riyadh
 * EAT
 * Europe/Moscow
 * Indian/Antananarivo
 * Indian/Comoro
 * Indian/Mayotte
 * Asia/Tehran
 * MET
 * Asia/Aqtau
 * Asia/Baku
 * Asia/Dubai
 * Asia/Muscat
 * Asia/Tbilisi
 * Asia/Yerevan
 * Europe/Samara
 * Indian/Mahe
 * Indian/Mauritius
 * Indian/Reunion
 * NET
 * Asia/Kabul
 * Asia/Aqtobe
 * Asia/Ashgabat
 * Asia/Ashkhabad
 * Asia/Bishkek
 * Asia/Dushanbe
 * Asia/Karachi
 * Asia/Tashkent
 * Asia/Yekaterinburg
 * Indian/Chagos
 * Indian/Kerguelen
 * Indian/Maldives
 * PLT
 * Asia/Calcutta
 * IST
 * Asia/Katmandu
 * Antarctica/Mawson
 * Asia/Almaty
 * Asia/Colombo
 * Asia/Dacca
 * Asia/Dhaka
 * Asia/Novosibirsk
 * Asia/Thimbu
 * Asia/Thimphu
 * BST
 * Asia/Rangoon
 * Indian/Cocos
 * Asia/Bangkok
 * Asia/Jakarta
 * Asia/Krasnoyarsk
 * Asia/Phnom_Penh
 * Asia/Saigon
 * Asia/Vientiane
 * Indian/Christmas
 * VST
 * Antarctica/Casey
 * Asia/Brunei
 * Asia/Hong_Kong
 * Asia/Irkutsk
 * Asia/Kuala_Lumpur
 * Asia/Macao
 * Asia/Manila
 * Asia/Shanghai
 * Asia/Singapore
 * Asia/Taipei
 * Asia/Ujung_Pandang
 * Asia/Ulaanbaatar
 * Asia/Ulan_Bator
 * Australia/Perth
 * CTT
 * Asia/Jayapura
 * Asia/Pyongyang
 * Asia/Seoul
 * Asia/Tokyo
 * Asia/Yakutsk
 * JST
 * Pacific/Palau
 * ACT
 * Australia/Adelaide
 * Australia/Broken_Hill
 * Australia/Darwin
 * AET
 * Antarctica/DumontDUrville
 * Asia/Vladivostok
 * Australia/Brisbane
 * Australia/Hobart
 * Australia/Sydney
 * Pacific/Guam
 * Pacific/Port_Moresby
 * Pacific/Saipan
 * Pacific/Truk
 * Australia/Lord_Howe
 * Asia/Magadan
 * Pacific/Efate
 * Pacific/Guadalcanal
 * Pacific/Kosrae
 * Pacific/Noumea
 * Pacific/Ponape
 * SST
 * Pacific/Norfolk
 * Antarctica/McMurdo
 * Asia/Anadyr
 * Asia/Kamchatka
 * NST
 * Pacific/Auckland
 * Pacific/Fiji
 * Pacific/Funafuti
 * Pacific/Majuro
 * Pacific/Nauru
 * Pacific/Tarawa
 * Pacific/Wake
 * Pacific/Wallis
 * Pacific/Chatham
 * Pacific/Enderbury
 * Pacific/Tongatapu
 * Pacific/Kiritimati
 */
