/********************************************************************
 *                   NASA CONFIDENTIAL INFORMATION                  *
 *               (c)2000-2001 Nasa Ames Research Center				*
 *                        All Rights Reserved                       *
 *                                                                  *
 *  This program contains confidential and proprietary information  *
 *  of NASA Ames Research Center, any reproduction, disclosure,     *
 *  or use in whole or in part is expressly prohibited, except as   *
 *  may be specifically authorized by prior written agreement.      *
 *                                                                  *
 ********************************************************************/

/********************************************************************
 * The JACExample model shows how Java Activities can be defined and
 * used in a Brahms model. This example show to java activities. One
 * class Hello World java activity that will display the Hello World
 * text to the console and one activity that concatenates two strings
 * and stores its results in an unbound variable.
 *
 * Build this example using the Brahms compiler V2.03.002 or higher
 * and run this example then using the Brahms virtual machine 
 * V2.00.0067 alpha. Make sure to include the path of this example
 * in the library path of the compiler and the virtual machine (modify
 * the vm.cfg file). Also make sure that the build path of the java 
 * activity is in the class path of the java virtual machine. You can 
 * add the build path to the virtual machine's classpath by editing the 
 * vm.cfg file. Add an entry 'class_path=<your path>'. If the entry
 * is already present, modify it to include your class path. 
 ********************************************************************/

/**
 * The agent that performs the two java activities in order.
 */
agent JACAgent {

	attributes:
		public string nextJavaActivity;
		public string performedActivity;
		public string text1;
		public string text2;
		public string result;

	initial_beliefs:
		// the java activity to be executed by the agent for Hello World */
		(current.nextJavaActivity = "gov.nasa.arc.brahms.jact.HelloWorldActivity");
		// The two strings that will be concatenated
		(current.text1 = "Hello ");
		(current.text2 = "World");

	activities:
		/**
		 * The sayHelloWorld activity could actually be used as a more
		 * generic activity since the class to be executed is passed
		 * as a parameter. An agent can therefor specify itself what java
		 * activity would have to be executed and pass the appropriate
		 * class into this activity.
		 */
		java sayHelloWorld(int maxd, string javacls, symbol whn) {
			max_duration: maxd;
			class: javacls;
			when: whn;
		} // sayHelloWorld
		
		/**
		 * This activity concatenates two string and stores its result
		 * in the out parameter. The parameter names have to be as
		 * specified as that is what the Java Activity developer specified
		 * in its api (see gov.nasa.arc.brahms.jact.string.ConcatActivity).
		 * The out parameter must be an unbound variable. The in parameters
		 * can be string values or bound variables.
		 */
		java concat(string in1, string in2, string out) {
			max_duration: 0;
			class: "gov.nasa.arc.brahms.jact.string.ConcatActivity";
			when: start;
		} // concat
		
	workframes:
		/**
		 * Executes the hello world java activity provided the nextJavaActivity
		 * value is known. It is known since we specified it as an initial belief
		 */
		workframe wf_jacOne {
			variables:
				forone(string) act;
			when(knownval(current.nextJavaActivity = act))
			do {
				sayHelloWorld(10, act, end);
				conclude((current.performedActivity = act), bc:100, fc:0);
			} // end do
		} // wf_jacOne

		/**
		 * Concatenates two strings. It uses the two beliefs about text1 and
		 * text2 to bind their values to the input variables. The output 
		 * variable out remains unbound. The result of the concatenation
		 * is assigned to the result attribute of the agent.
		 */
		workframe wf_concat {
			variables:
				forone(string) in1;
				forone(string) in2;
				forone(string) out;
			when(knownval(current.text1 = in1) and
				 knownval(current.text2 = in2))
			do {
				concat(in1, in2, out);
				conclude((current.result = out), bc:100, fc:100);
				conclude((current.performedActivity = "concat"), bc:100, fc:0);
			} // end do
		} // wf_concat
} // JACAgent

